<?php
/**
 * Woocommerce Compatibility.
 *
 * @link https://woocommerce.com/
 *
 * @package Dolpa
 */

if (class_exists('WooCommerce')) {

    remove_action( 'woocommerce_before_main_content','woocommerce_breadcrumb',20 );
    remove_action( 'woocommerce_sidebar','woocommerce_get_sidebar',10 );

}
/**
* Woocommerce Widget Area.
*/
function dolpa_woocommerc_widgets_init()
{   

    register_sidebar( array(
        'name' => esc_html__('WooCommerce Sidebar', 'dolpa'),
        'id' => 'dolpa-woocommerce-widget',
        'description' => esc_html__('Add widgets here.', 'dolpa'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ));

}

if (class_exists('WooCommerce')) {
    add_action('widgets_init', 'dolpa_woocommerc_widgets_init');
}

if (!function_exists('dolpa_woocommerce_scripts')):

    /**
     * Woocommerce support.
     */
    function dolpa_woocommerce_setup()
    {

        add_theme_support('woocommerce');
        add_theme_support('wc-product-gallery-zoom');
        add_theme_support('wc-product-gallery-lightbox');
        add_theme_support('wc-product-gallery-slider');
        add_theme_support('woocommerce', array(
            'gallery_thumbnail_image_width' => 300,
        ));

    }

endif;

add_action('after_setup_theme', 'dolpa_woocommerce_setup');

if (!function_exists('dolpa_woocommerce_scripts')):

    /**
     * Woocommerce Enqueue Scripts.
     */
    function dolpa_woocommerce_scripts()
    {

        $dolpa_dir_uri = get_template_directory_uri();
        if (class_exists('WooCommerce')) {

            wp_enqueue_style('dolpa-woocommerce', $dolpa_dir_uri . '/assets/lib/custom/css/woocommerce.css');

        }

    }

endif;

add_action('wp_enqueue_scripts', 'dolpa_woocommerce_scripts');

if (!function_exists('dolpa_woocommerce_before_main_content')):

    // Before Main Content woocommerce hook
    function dolpa_woocommerce_before_main_content()
    {

        echo '<div class="singular-main-block">';
        echo '<div class="wrapper">';
        echo '<div class="wrapper-inner">';
    }

endif;

if (class_exists('WooCommerce')) {
    add_action('woocommerce_before_main_content', 'dolpa_woocommerce_before_main_content', 5);
}

if (!function_exists('dolpa_woocommerce_after_main_content')):

    // After Main Content woocommerce hook
    function dolpa_woocommerce_after_main_content()
    {

    	$default = dolpa_get_default_theme_options();
        $sidebar_layout = esc_html(get_theme_mod('global_sidebar_layout', ''));

        if ($sidebar_layout != 'no-sidebar') {
            if (!is_active_sidebar('dolpa-woocommerce-widget')) {
                return;
            } ?>
            <aside id="secondary" class="widget-area">
                <?php dynamic_sidebar('dolpa-woocommerce-widget'); ?>
            </aside><!-- #secondary -->
        <?php }
        
        echo '</div>';
        echo '</div>';
        echo '</div>';
    }

endif;

if (class_exists('WooCommerce')) {
    add_action('woocommerce_after_main_content', 'dolpa_woocommerce_after_main_content', 15);
}

if (!function_exists('dolpa_check_woocommerce_page')):

    // Check if woocommerce pages.
    function dolpa_check_woocommerce_page()
    {

        if (!class_exists('WooCommerce')):
            return false;
        endif;

        if (is_woocommerce() || is_cart() || is_checkout() || is_account_page()) {
            return true;
        } else {
            return false;
        }

    }
endif;

if (!function_exists('dolpa_header_mini_cart')):

    function dolpa_header_mini_cart()
    {

        if (class_exists('WooCommerce')) { ?>

            <button type="button" class="navbar-control button-style navbar-control-cart">


                <?php dolpa_the_theme_svg('cart'); ?>

                <div class="twp-minicart-content">
                    <?php
                    $instance = array(
                        'title' => '',
                    );

                    the_widget('WC_Widget_Cart', $instance);
                    ?>
                </div>

            </button>

            <?php

        }
    }

endif;